==> haskell-mono-traversable-instances-0.1.1.0-355-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-8qHskX3P7J1DX6R4eQ3l1T
key:                  mono-traversable-instances-0.1.1.0-8qHskX3P7J1DX6R4eQ3l1T
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  842288603993cdfb4ef11cac2e61290e
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-8qHskX3P7J1DX6R4eQ3l1T
depends:
    base-4.17.2.1 comonad-5.0.9-7Nx7TLF48pI5LjqSes8omR containers-0.6.7
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    dlist-instances-0.1.1.1-1PF5b6vAvpMH0LL2Cykwfs
    mono-traversable-1.0.21.0-7ORvxyI1bVCJe51jZHn0i8
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR transformers-0.5.6.2
    vector-instances-3.4.3-C0uSgtYOdPMDMMcqe0pxUg

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-instances-0.1.1.0-374-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-6fApgq3j7Le2mD329TcjdA
key:                  mono-traversable-instances-0.1.1.0-6fApgq3j7Le2mD329TcjdA
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  14f2348498e4e838a6c4f7fb817e06af
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-6fApgq3j7Le2mD329TcjdA
depends:
    base-4.17.2.1 comonad-5.0.9-69ztrEylAHVD4BHHoJEwKX containers-0.6.7
    dlist-1.0-DlYyWPxbaG7vpSilKIFCh
    dlist-instances-0.1.1.1-JYdQJ62ClOLBF4youDn3zC
    mono-traversable-1.0.21.0-48l2Xi79dD45KeFaMEMJQI
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J transformers-0.5.6.2
    vector-instances-3.4.3-HNE41dQsCL5JeIKsGsqeHY

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
